pub enum WasmVal {
I32(i32),
I64(i64),
F32(u32),
F64(u64),
}Expand description
A WASM numeric value, used for function call arguments and return values.
F32 and F64 are stored as their bit representations (u32 and u64)
so that WasmVal can derive Eq and remain free of IEEE754 float
comparison edge cases.
Variants